@@ -1,5 +1,5 @@
-#define VERSION	"2.4.2"
-#define DATE	"21 Jan 1996"
+#define VERSION	"2.4.5"
+#define DATE	"28 Sep 1998"
 
 /*
  * Version 1.68		        1985		Mark Brukhartz
@@ -13,4 +13,7 @@
  * Version 2.4                  26 Nov 94       Anders Baekgaard, Koen Holtman
  * Version 2.4.1                08 Feb 95       Koen Holtman
  * Version 2.4.2                21 Jan 96       Koen Holtman
+ * Version 2.4.3                15 May 98       Koen Holtman
+ * Version 2.4.4                21 Jun 98       Koen Holtman
+ * Version 2.4.5                28 Sep 98       Koen Holtman
  */
